@@ -2,10 +2,37 @@ GeoNeighborhood = function(data=NULL, coordx, coordy=NULL, coordt=NULL, coordx_d
             distance="Eucl", grid=FALSE, loc, neighb=NULL,maxdist=NULL,maxtime=NULL,
                  radius=6371, time=NULL, X=NULL,M=NULL)
 {
+  #####################
+    nbor=function(coords,loc,distance,maxdist,neighb){
+  ### to improve!
+  if(distance=="Geod"||distance=="Chor")
+  {
+    coords_p=coords; loc_p=loc
+    prj=mapproj::mapproject(coords_p[,1], coords_p[,2], projection="sinusoidal") 
+    coords_p=radius*cbind(prj$x,prj$y)
+    prjloc=mapproj::mapproject(loc_p[,1], loc_p[,2], projection="sinusoidal")
+    loc_p=radius*cbind(prjloc$x,prjloc$y)
+  }
+  ##################################################################################
+  searchtype = "standard"
+  if(!is.null(maxdist)){searchtype = "radius"} else {maxdist=0}
+  if(is.null(neighb)) neighb=min(100, NN)
   
+  ## computing neigh indexes
+  if(distance=="Geod"||distance=="Chor")  {
+                                           #out<- RANN::nn2(coords_p,loc_p, k=neighb,searchtype=searchtype,radius=maxdist)
+                                           out<- nabor::knn(coords_p,loc_p, k=neighb,radius=maxdist)
+                                           }
+  if(distance=="Eucl")                    {
+                                          # out<- RANN::nn2(coords,loc,     k=neighb,searchtype=searchtype,radius=maxdist)
+                                           out<- nabor::knn(coords,loc, k=neighb,radius=maxdist)
+                                          }
+    return(out)                                       
+    }
+  #####################  
   
   XX=NULL
-  M_sel=NULL
+  MM=NULL
   numtime=1
   sel_ss=1
   sel_tt=1
@@ -14,7 +41,6 @@ GeoNeighborhood = function(data=NULL, coordx, coordy=NULL, coordt=NULL, coordx_d
   if(!is.logical(bivariate))   stop("bivariate must be logical")
   #if(!(ncol(loc)==2))   stop("loc parameter must be a matrix  N X 2")
   if(is.null(neighb)&&is.null(maxdist))     stop("maxdist (maxtime) and/or neighb must  be specified")
-  if(!is.null(maxtime)) maxtime=round(maxtime)
   if(!is.null(neighb)) neighb=round(neighb)
 
   spacetime=FALSE
@@ -23,6 +49,9 @@ GeoNeighborhood = function(data=NULL, coordx, coordy=NULL, coordt=NULL, coordx_d
   
   dyn=FALSE
   if(!is.null(coordx_dyn))  dyn=TRUE  
+
+ 
+
   ## handling spatial coordinates
   if(is.null(coordy)) {coords=as.matrix(coordx)}else{
     if(grid) {coords=as.matrix(expand.grid(coordx,coordy))}
@@ -36,85 +65,91 @@ GeoNeighborhood = function(data=NULL, coordx, coordy=NULL, coordt=NULL, coordx_d
   colnames(loc)=NULL;colnames(coords)=NULL;
   space=!spacetime&&!bivariate 
   ##################################################################
-  
-  ### to improve!
-  if(distance=="Geod"||distance=="Chor")
-  {
-    coords_p=coords; loc_p=loc
-    prj=mapproj::mapproject(coords_p[,1], coords_p[,2], projection="sinusoidal") 
-    coords_p=radius*cbind(prj$x,prj$y)
-    prjloc=mapproj::mapproject(loc_p[,1], loc_p[,2], projection="sinusoidal")
-    loc_p=radius*cbind(prjloc$x,prjloc$y)
-  }
-  
-  ##################################################################################
-  ##################################################################################
-  
-  searchtype = "standard"
-  if(!is.null(maxdist)){searchtype = "radius"}else {maxdist=0}
-  if(is.null(neighb)) neighb=min(100, NN)
-  
-  ## computing neigh indexes
-  if(distance=="Geod"||distance=="Chor")  {
-                                           #out<- RANN::nn2(coords_p,loc_p, k=neighb,searchtype=searchtype,radius=maxdist)
-                                           out<- nabor::knn(coords_p,loc_p, k=neighb,radius=maxdist)
-                                           }
-  if(distance=="Eucl")                    {
-                                          # out<- RANN::nn2(coords,loc,     k=neighb,searchtype=searchtype,radius=maxdist)
-                                           out<- nabor::knn(coords,loc, k=neighb,radius=maxdist)
-                                          }
+
+
+
+
+
   #################################
   if(space){
-    sel_ss=data_sel=numpoints=XX=M_sel=list()
+
+    sel_ss=data_sel=numpoints=XX=MM=list()
+    out= nbor(coords,loc,distance,maxdist,neighb)
     for(i in 1:Nloc)
     {
       ss=out$nn.idx[i,];
       sel_ss[[i]]=coords[ss,]
       numpoints[[i]]=nrow(sel_ss[[i]])
       if(!is.null(data)) data_sel[[i]]=data[ss]
-      if(!is.null(M)) M_sel[[i]]=M[ss]
+      if(!is.null(M)) MM[[i]]=M[ss]
       if(!is.null(X)) XX[[i]]=X[ss,]
     }
   }
-
   #####################################################################################
-  if(spacetime)
+  if(spacetime) 
   {
-    Tloc=length(time); TT=length(coordt)   
-    out_t <- nabor::knn(coordt,time,k=maxtime)$nn.idx
- 
-    out_t <- list(ind=cbind(as.vector(out_t),seq(time)))
 
-    sel_ss=numpoints=data_sel=sel_tt=XX=M_sel=list()
+
+if(!dyn){  # not dynamic
+
+    Tloc=length(time); TT=length(coordt)   
+    out= nbor(coords,loc,distance,maxdist,neighb)
+    if(!is.null(M)) { Mma=matrix(M,nrow=TT,ncol=NN)}
+    if(!is.null(X)) { Xxa=list(); for(i in 1:ncol(X)) {Xxa[[i]]=matrix(X[,i],nrow=TT,ncol=NN)}}
+  
+
+
+    out_t <- nabor::knn(coordt,time,k=length(coordt),radius=maxtime) # with distance
+
+    #out_t <- nabor::knn(coordt,time,k=round(maxtime)+1) #with neighboord 
+
+
+    qq=out_t$nn.idx[1,];ss=which(qq!=0)
+    out_t <- list(ind=cbind(as.vector(out_t$nn.idx[,ss]),time))
+
+    sel_ss=numpoints=data_sel=sel_tt=XX=MM=list()
+ 
     k=1
-    for(i in 1:Nloc){
-      sel_s=out$nn.idx[i,];
-      sel_ss[[i]]=matrix(coords[sel_s,],ncol=2)
-      for(j in 1:Tloc){
-        sel_t=out_t$ind[,1][out_t$ind[,2]==j]
-        sel_tt[[j]]=coordt[sel_t]
-        if(!is.null(data)) data_sel[[k]]=data[sel_t,sel_s]
-       # if(!is.null(M)) M_sel[[k]]=data[sel_t,sel_s]   to improveeeee
-        k=k+1
-      }
-      if(!is.null(X)) {
-        sss=NULL;
-        for (l in 1:Tloc) sss=c(sss,sel_s+(l-1)*Nloc)
-        XX[[i]]=X[sss,]
-      }
+    for(i in 1:Nloc)
+    {
+      for(j in 1:Tloc)
+       {
+       sel_s=out$nn.idx[i,];
+       sel_ss[[k]]=matrix(coords[sel_s,],ncol=2)
+       numpoints[[k]]=nrow(sel_ss[[i]])
+       
+          sel_t=out_t$ind[,1][out_t$ind[,2]==time[j]]
+          pp=order(coordt[sel_t])
+          sel_tt[[k]]=coordt[sel_t][pp]
+          if(!is.null(data)) data_sel[[k]]=(data[sel_t,sel_s])[pp,]
+          if(!is.null(M))   { MM[[k]]=as.numeric( (Mma[sel_t,sel_s])[pp,] ) }
+          if(!is.null(X))   {   
+                              KK=NULL
+                              for(l in 1:ncol(X)) { KK=cbind(KK,as.numeric( (Xxa[[l]][sel_t,sel_s])[pp,] )) }
+                              XX[[k]]=KK       
+                            }
+       k=k+1
+       }
     }
-  }
+}  # end not dynamic
+  if(dyn) print("to fix")  #dynamic
+
+}
   #####################################################################################
-  if(bivariate)
+  if(bivariate)   #### to fix case dyn
   {
     Nloc=nrow(loc)
-    if(dyn) coords=rbind(coords,coords)
-    sel_ss=numpoints=data_sel=sel_tt=XX=M_sel=list()
+    if(dyn) coords=rbind(coords[[1]],coords[[2]])
+    sel_ss=numpoints=data_sel=sel_tt=XX=MM=list()
+    if(dyn)      {out1= nbor(coords[[1]],loc,distance,maxdist,neighb)
+                 out2= nbor(coords[[2]],loc,distance,maxdist,neighb)}
+    else  {out= nbor(coords,loc,distance,maxdist,neighb)}
+     
     for(i in 1:Nloc){
       sel=out$nn.idx[i,]
       sel_ss[[i]]=coords[sel,]
       numpoints[[i]]=ncol(sel_ss[[i]])
-      if(!is.null(M)) {M_sel[[i]]=cbind(M[ss,1],M[ss,2])}
+      if(!is.null(M)) {MM[[i]]=cbind(M[ss,1],M[ss,2])}
       if(!is.null(data))data_sel[[i]]=matrix(data[,sel],nrow=2)
       if(!is.null(X))   XX[[i]]=X[c(sel,2*sel),]
     }
@@ -122,10 +157,10 @@ GeoNeighborhood = function(data=NULL, coordx, coordy=NULL, coordt=NULL, coordx_d
   ##################################################################################
   ##################################################################################
   ##################################################################################
-
+  if(length(MM)==0)  MM=NULL
   if(length(XX)==0) XX=NULL
   if(length(data_sel)==0) data_sel=NULL
-  if(length(M_sel)==0) M_sel=NULL
+ 
   return(list(data=data_sel,coordx=sel_ss,coordt=sel_tt,distance=distance, 
-              numpoints=numpoints,numtime=numtime,radius=radius,spacetime=spacetime,X=XX,M=M_sel))
+              numpoints=numpoints,numtime=numtime,radius=radius,spacetime=spacetime,X=XX,M=MM))
 } 
\ No newline at end of file
